@@ -3,9 +3,11 @@ from .input_types import (
     MainInput,
     StringInput,
     StringArrayInput,
+    StringArrayInputInline,
     NumberInput,
     SelectInput,
     CheckboxInput,
+    SwitchInput,
     FileInput,
     FilesInput,
     SelectOption
@@ -16,9 +18,11 @@ __all__ = [
     "MainInput",
     "StringInput", 
     "StringArrayInput",
+    "StringArrayInputInline",
     "NumberInput",
     "SelectInput",
     "CheckboxInput",
+    "SwitchInput",
     "FileInput",
     "FilesInput",
     "SelectOption"
